<?php

class TT_Proven_EDD {
    /**
     * Holds the class object.
     *
     * @since 1.0.0
     * @var object
     */
    public static $instance;

    /**
     * Primary class constructor
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        add_action( 'plugins_loaded', array( $this, 'init_hooks' ) );
    }

	/**
     * Initialize the hooks.
     *
     * @since 1.0.0
     * @return void
     */
    public function init_hooks()
    {
        if ( ! class_exists( 'edd' ) ) {
            Proven_Admin::$errors[] = esc_html__( 'Please install and activate Easy Digital Downloads.', 'tt-proven' );
            return;
        }
    }

    /**
     * Get orders.
     */
    static public function get_payments( $max = '-1' )
    {
        $args = array(
            'number'    => $max,
            'status'    => array('publish')
        );

        return edd_get_payments( $args );
    }

    static public function get_payments_by_product( $product_id, $max = '' )
    {
        $payments = array();
        $logs = self::get_logs_by_product( $product_id, $max );
        foreach ( $logs as $log ) {
            if ( count( $payments ) == $max ) {
                continue;
            }

            $payment_id = get_post_meta( $log->ID, '_edd_log_payment_id', true );
            $payment = get_post( $payment_id );

            if ( 'publish' == $payment->post_status ) {
                $payments[] = $payment;
            } else {
                continue;
            }
        }

        return $payments;
    }

    static public function get_logs_by_product( $product_id, $max )
    {

        if ( empty( $max ) ) {
            $max = '-1';
        }

        $args = array(
            'post_type'         => 'edd_log',
			'posts_per_page'    => $max,
			'post_status'       => 'publish',
            'post_parent'       => $product_id,
            'tax_query'         => array(
                array(
                    'taxonomy'  => 'edd_log_type',
					'field'     => 'slug',
					'terms'     => array('sale'),
                )
            )
        );

        $logs = get_posts( $args );

        return $logs;
    }

    /**
     * Get payment info.
     */
    static public function get_payment_details( $payment_id )
    {
        $info = edd_get_payment_meta( $payment_id );

        if ( ! $info ) {
            return;
        }

        return $info;
    }

    /**
     * Get all downloads from payment.
     */
    static public function get_payment_downloads( $payment_id )
    {
        $downloads = edd_get_payment_meta_downloads( $payment_id );

        if ( ! $downloads ) {
            return;
        }

        return $downloads;
    }

    /**
     * Get customer data.
     */
    static public function get_customer( $payment_id )
    {
        $payment = new EDD_Payment( $payment_id );
		$customer_info      = $payment->user_info;
		
		if ( ! $customer_info ) {
            return;
        }
		
		$customer                  = array();
		$customer['first_name']    = $customer_info['first_name'];
		$customer['last_name']     = $customer_info['last_name'];
		$customer['email']         = $customer_info['email'];
		$customer['city']          = $customer_info['address']['city'];
		$customer['state']         = $customer_info['address']['state'];
		$customer['country']       = $customer_info['address']['country'];

        return $customer;
    }

    /**
     * Get the date of the payment.
     */
    static public function get_payment_date( $payment_id )
    {
        $payment_date = edd_get_payment_completed_date( $payment_id );

        if ( ! $payment_date ) {
            return;
        }

        return $payment_date;
    }

	/**
     * Get all products.
     */
    static public function get_products( $max = '-1' )
    {
        $args = array(
            'post_type'         => 'download',
            'post_status'       => 'publish',
            'posts_per_page'    => $max
        );

        return get_posts( $args );
    }

    static public function get_products_list( $max = '-1' )
    {
        $products = self::get_products( $max );
        $options  = array( '' => __('All Products', 'tt-proven') );

        foreach ( $products as $product ) {
            $options[$product->ID] = $product->post_title;
        }

        return $options;
    }

	/**
     * Add EDD activity.
     *
     * @since 1.0.0
     * @return array
     */
    public function get_activity_data( $id )
    {
        if ( 'edd' != get_post_meta( $id, '_tt_proven_source', true ) ) {
            return $data;
        }
		
		//Number of purcahses to show
		$number = get_post_meta( $id, '_tt_proven_number', true );
		
		//Specific product or all products
		$specific_product = get_post_meta( $id, '_tt_proven_purchases_edd', true );
		
        if ( ! $payments || empty( $payments ) ) {
            if ( '' != $specific_product ) {
                $payments = self::get_payments_by_product( $specific_product, $number );
            } else {
                $payments = self::get_payments( $number );
            }
        }

		$notification_order = get_post_meta( $id, '_tt_proven_order', true ); //Determine what order the notifications should be displayed
		if($notification_order == 'random'){
			shuffle($payments);
		}

		$link_to = get_post_meta( $id, '_tt_proven_link_to', true );

        foreach ( $payments as $payment ) {

            if ( '' != $specific_product ) {
                $product[] = array(
                    'id' => $specific_product
                );
            } else {
                // Get a product from order.
                $product = self::get_payment_downloads( $payment->ID );
            }

            if ( ! $product || empty( $product ) ) {
                continue;
            }

            $product = $product[0];
			$product_id = $product['id'];
            $product_name = get_the_title( $product['id'] );

            // Get the customer info.
            $customer = self::get_customer( $payment->ID );

			$time = human_time_diff(strtotime(self::get_payment_date( $payment->ID )), current_time( 'timestamp' ));

            ob_start();
            ?>
            <small><?php echo esc_html__( 'About', 'tt-proven' ) . ' ' . esc_html( $time ) . ' ' . esc_html__( 'ago', 'tt-proven' ) ?></small>
            <?php
            $time_ago = ob_get_clean();
			
            // Data for box.
            $activity_data = array(
                'title'           => $product_name,
                'name'            => $customer['first_name'],
				'email'           => $customer['email'],
				'city'            => $customer['city'],
				'state'           => $customer['state'],
				'country'         => $customer['country'],
                'time'            => $time_ago
            );

			if(!$activity_data['name']){
				$activity_data['name'] = __( 'Someone', 'tt-proven' );
			}

            // Product URL or Custom URL.
            if ( $link_to == 'product' ) {
                $activity_data['link_url'] = get_permalink( $product_id );
            }elseif($link_to == 'custom'){
				$activity_data['link_url'] = get_post_meta( $id, '_tt_proven_custom_url_ecommerce', true );
			}

            $data['fields'][] = $activity_data;
        }

        $data['template'] = get_post_meta( $id, '_tt_proven_content_ecommerce', true );

        return $data;
    }

	/**
	 * Returns the singleton instance of the class.
	 *
	 * @since 1.0.0
	 * @return object The TT_Proven_EDD object.
	 */
	public static function get_instance()
	{
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof TT_Proven_EDD ) ) {
			self::$instance = new TT_Proven_EDD();
		}

		return self::$instance;
	}
}

$tt_proven_edd = TT_Proven_EDD::get_instance();
