<?php

class TT_Proven_MailChimp {
	
	
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	
    /**
     * Holds the class object.
     *
     * @since 1.0.0
     * @var object
     */
    public static $instance;
	
	/**
	 * @since 1.0.0
	 * @var object $api_instance
	 */
	static private $api_instance = null;
	

	/**
	 * Get an instance of the API.
	 *
	 * @since 1.0.0
	 */
	static public function get_api( $api_key )
	{
		if ( self::$api_instance ) {
			return self::$api_instance;
		}
		if ( ! class_exists( 'Mailchimp' ) ) {
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/mailchimp/mailchimp.php';
		}

		self::$api_instance = new Mailchimp( $api_key );

		return self::$api_instance;
	}
	
	/**
	 * API connection.
	 *
	 * @since 1.0.0
	 */
	public function connect( $api_key = '' )
	{
		$response = array(
			'error'  => false,
			'data'   => array()
		);

		// Make sure we have an API key.
		if ( empty( $api_key ) ) {
			$response['error'] = __( 'Error: You must provide an API key.', 'tt-proven' );
		}
		// Try to connect and store the connection data.
		else {

			$api = self::get_api( $api_key );

			try {
				$api->helper->ping();
				$response['data'] = array( 'api_key' => $api_key );
			}
			catch ( Mailchimp_Invalid_ApiKey $e ) {
				$response['error'] = $e->getMessage();
			}
            catch ( Mailchimp_Error $e ) {
                $response['error'] = $e->getMessage();
            }
		}

		return $response;
	}


    /**
     * Connect MailChimp via AJAX request.
     *
     * @since 1.0.0
     */
    public function tt_proven_connect_mailchimp() {
		
        $response = array(
			'error'  => false,
			'html'   => ''
		);

        if ( ! isset( $_POST['api_key'] ) || empty( $_POST['api_key'] ) ) {
            $response['error'] = __('Error: You must provide an API key.', 'tt-proven');
        }

        if ( ! $response['error'] ) {

            $api_key = $_POST['api_key'];
            $connection = self::connect( $api_key );

            if ( $connection['error'] ) {
                $response['error'] = $connection['error'];
            }
            else {
                $post_id = isset( $_POST['post_id'] ) ? $_POST['post_id'] : '';
                $list_id = false;

                if ( ! empty( $post_id ) ) {
                    $list_id = get_post_meta( $post_id, 'tt_proven_mailchimp_list', true );
                }

                $api = self::get_api( $api_key );

                // Lists field html.
        		try {
                    $lists = $api->lists->getList();

                    update_option( 'tt_proven_mailchimp_lists', $lists );
        		}
        		catch ( Mailchimp_Error $e ) {
        			$response['error'] = $e->getMessage();
        		}
            }
        }

        echo json_encode( $response ); die();
    }

    /**
     * Get lists from saved option.
     *
     * @since 1.0.0
     * @return array
     */
    static public function get_mailing_lists()
    {
        $lists = get_option( 'tt_proven_mailchimp_lists' );
        $options = array();

        if ( is_array( $lists ) && ! empty( $lists ) ) {
            foreach ( $lists['data'] as $list ) {
                $options[$list['id']] = $list['name'];
            }
        }

        return $options;
    }

    
    /**
     * Add signup data from MailChimp.
     *
     * @since 1.0.0
     */
    public function get_activity_data( $id )
    {
        if ( 'mailchimp' != get_post_meta( $id, '_tt_proven_source', true ) ) {
            return $data;
        }

        $number = get_post_meta( $id, '_tt_proven_number', true );

        if ( empty( $number ) || ! $number ) {
            $number = 30;
        }

        $subscribers = get_post_meta( $id, '_tt_proven_mailchimp_subscribers', true );

        if ( empty( $subscribers ) ) {
            return $data;
        }
        if ( empty( $subscribers['data'] ) || $subscribers['total'] == 0 ) {
            return $data;
        }

		$notification_order = get_post_meta( $id, '_tt_proven_order', true ); //Determine what order the notifications should be displayed
		if($notification_order == 'random'){
			shuffle($subscribers['data']);
		}

        foreach ( $subscribers['data'] as $subscriber ) {

            $activity_data = array(
                'title'     => $subscriber['list_name'],
                'name'      => $subscriber['merges']['FNAME'],
                'email'     => $subscriber['email'],
                'time'      => ''
            );

            if ( isset( $subscriber['timestamp_opt'] ) && ! empty( $subscriber['timestamp_opt'] ) ) {
                $time = human_time_diff( strtotime( $subscriber['timestamp_opt'] ), current_time( 'timestamp' ) );
                ob_start();
                ?>
                <small><?php echo esc_html__( 'About', 'tt-proven' ) . ' ' . esc_html( $time ) . ' ' . esc_html__( 'ago', 'tt-proven' ) ?></small>
                <?php
                $time_ago = ob_get_clean();

                $activity_data['time'] = $time_ago;
            }

			//Check in there is a name and it is not an email address. Do not want to show email addresses to the public.
			if(!$activity_data['name'] || strpos($activity_data['name'], '@') !== false){
				$activity_data['name'] = __( 'Someone', 'tt-proven' );
			}
            $data['fields'][] = $activity_data;
        }

        $data['template'] = get_post_meta( $id, '_tt_proven_content_mailchimp', true );

        return $data;
    }


	static public function get_subscirbers_api( $api_key = '', $list_id = '', $number = 30 )
    {
        $response = array(
			'error'      => false,
			'subscribers'    => array()
		);

        // Make sure we have an API key.
		if ( empty( $api_key ) ) {
			$response['error'] = __( 'Error: You must provide an API key.', 'tt-proven' );
		}

        // Make sure we have list id.
		if ( empty( $list_id ) ) {
			$response['error'] = __( 'Error: You must provide a list ID.', 'tt-proven' );
		}

        if ( ! $response['error'] ) {
            $api = self::get_api( $api_key );

            try {
                $members = $api->lists->members( $list_id, 'subscribed', array( 'limit' => $number, 'sort_field' => 'optin_time', 'sort_dir' => 'DESC' ) );
                $response['subscribers'] = $members;
            }
            catch ( Mailchimp_HttpError $e ) {
                $response['error'] = $e->getMessage();
            }
        }

        return $response;
    }


    /**
     * Get saved subscribers.
     *
     * @since 1.0.0
     */
    public function get_subscribers( $post_id )
    {
        $source = get_post_meta( $post_id, '_tt_proven_source', true );

        if ( 'mailchimp' != $source ) {
            return;
        }

        
		if ( isset( $_POST['_tt_proven_mailing_list'] ) ) {
			$list_id = $_POST['_tt_proven_mailing_list'];
		}else{
			$list_id = get_post_meta( $post_id, '_tt_proven_mailing_list', true );
		}
		
        // Return if mailchimp list field is empty.
        if ( ! $list_id || empty( $list_id ) ) {
            return;
        }

        // Get api key.
        $api_key = get_option( 'tt_proven_mailchimp_api_key' );


        // Return if api key is empty.
        if ( ! $api_key || empty( $api_key ) ) {
            return;
        }

        // Get number of subscribers to show.
		if ( isset( $_POST['_tt_proven_number'] ) ) {
			$number = $_POST['_tt_proven_number'];
		}else{
			$number = get_post_meta( $post_id, '_tt_proven_number', true );
		}

        // Set a fallback of 30
        if ( empty( $number ) || ! $number ) {
            $number = 30;
        }

        // Get response from mailchimp.
        $response = self::get_subscirbers_api( $api_key, $list_id, $number );
        $subscribers = $response['subscribers'];

        return $subscribers;
    }

    /**
     * Cron job to get mailchimp subscribers.
     *
     * @since 1.0.0
     */
    public function fetch_subscriber_cron_job( $post_id )
    {
        // Verify if this is an auto save routine.
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
            return $post_id;
        }
		
		$source = get_post_meta( $post_id, '_tt_proven_source', true );
		if(get_post_type($post_id) == 'tt_proven' && $source == 'mailchimp'){
			
	        if ( 'mailchimp' != $source ) {
	            return;
	        }

        	$subscribers = self::get_subscribers( $post_id );

        	// Update subscribers in post meta.
        	update_post_meta( $post_id, '_tt_proven_mailchimp_subscribers', $subscribers );

        	// Clear previous cron hook.
        	wp_clear_scheduled_hook( 'tt_proven_mailchimp_get_subscribers_cron', array( 'post_id' => $post_id ) );

        	// If there is no next event, start cron now.
        	if ( ! wp_next_scheduled ( 'tt_proven_mailchimp_get_subscribers_cron', array( 'post_id' => $post_id ) ) ) {
    	    	wp_schedule_event( time(), 'twicedaily', 'tt_proven_mailchimp_get_subscribers_cron', array( 'post_id' => $post_id ) );
        	}

        	// Cron hook.
        	add_action( 'tt_proven_mailchimp_get_subscribers_cron', array( $this, 'schedule_subscribers' ) );
		}
    }

    /**
     * Cron job to fetch mailchimp subscribers.
     *
     * @since 1.0.0
     * @param array $args
     * @return void
     */
    public function schedule_subscribers( $args = array() )
    {
        if ( empty( $args ) ) {
            return;
        }

        $post_id = $args['post_id'];

        $subscribers = self::get_subscribers( $post_id );

        // Update fetched members in post meta.
        update_post_meta( $post_id, '_tt_proven_mailchimp_subscribers', $subscribers );
    }

    /**
	 * Returns an instance of the class.
	 *
	 * @since 1.0.0
	 */
	public static function get_instance()
	{
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof TT_Proven_MailChimp ) ) {
			self::$instance = new TT_Proven_MailChimp();
		}

		return self::$instance;
	}
}
