<?php

class TT_Proven_WooCommerce {
    /**
     * Holds the class object.
     *
     * @since 1.0.0
     * @var object
     */
    public static $instance;

    /**
     * Primary class constructor
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        add_action( 'plugins_loaded', array( $this, 'init_hooks' ) );
    }



    /**
     * Initialize the hooks.
     *
     * @since 1.0.0
     * @return void
     */
    public function init_hooks()
    {
        if ( ! class_exists( 'WooCommerce' ) ) {
            Proven_Admin::$errors[] = esc_html__( 'Please install and activate Woocommerce.', 'tt-proven' );
            return;
        }

        //add_filter( 'tt_proven_activity_data', array( $this, 'get_activity_data' ), 10, 2 );
    }

	/**
     * Get orders.
     */
    static public function get_orders( $max = '-1', $ids = false )
    {
        $args = array(
            'post_type'         => 'shop_order',
            'posts_per_page'    => $max,
            'post_status'       => array('wc-completed', 'wc-processing', 'wc-pending')
        );

        $orders = get_posts( $args );

        if ( $ids ) {
            $order_ids = array();
            foreach ( $orders as $order ) {
                $order_ids[] = $order->ID;
            }
        }

        return $orders;
    }

    static public function get_orders_by_product( $product_id, $max = '-1' )
    {
        global $wpdb;
        $order_ids_sql  = $wpdb->prepare( "SELECT order_id FROM {$wpdb->prefix}woocommerce_order_items WHERE order_item_id IN (SELECT order_item_id FROM {$wpdb->prefix}woocommerce_order_itemmeta WHERE meta_value = %d) LIMIT ". $max, $product_id );
        $order_ids      = $wpdb->get_results( $order_ids_sql );
        $orders         = array();

        if ( null == $order_ids || empty( $order_ids ) ) {
            return;
        }
        if ( is_array( $order_ids ) ) {
            foreach ( $order_ids as $order_ids_single ) {
                $orders[] = $order_ids_single->order_id;
            }
        }

        return $orders;
    }

    /**
     * Get a product from order.
     */
    static public function get_product_from_order( $order_id, $product_id = '' )
    {
        // Get the order items.
        $order = wc_get_order( $order_id );

        if ( ! $order ) {
            return;
        }

        $products = array();

        foreach( $order->get_items() as $item_key => $item_values ) {
            // get_data array keys:
            // 'name', 'product_id', 'variation_id', 'quantity',
            // 'tax_class', 'subtotal', 'subtotal_tax', 'total',
            // 'total_tax'
            $products[] = array(
                'id'    => $item_values->get_id(),
                'data'  => $item_values->get_data()
            );
        }

        if ( !is_array( $products ) || ! count( $products ) ) {
            return;
        }

        return $products[0];
    }

    /**
     * Get billing address from order.
     */
    static public function get_address( $order_id, $key = '' )
    {
        // Get the order.
        $order = wc_get_order( $order_id );

        // Get the order data.
        $order_data = $order->get_data();

        if ( empty( $key ) ) {
            return $order_data;
        }
        // $key can be:
        // 'first_name', 'last_name', 'company', 'address_1', 'address_2',
        // 'city', 'state', 'postcode', 'country', 'email', 'phone'
        if ( isset( $order_data[$key] ) ) {
            return $order_data[$key];
        }
    }

    static public function get_products( $max = '-1' )
    {
        global $wpdb;

        $type = 'product';

        $posts = $wpdb->get_results( $wpdb->prepare( "
            SELECT * FROM {$wpdb->posts}
            WHERE post_type = %s
            AND post_status = 'publish'
            ORDER BY post_date DESC
        ", $type ) );

        return $posts;
    }

    static public function get_products_list( $max = '-1' )
    {
        global $wpdb;

        $type = 'product';

        $posts = $wpdb->get_results( $wpdb->prepare( "
            SELECT ID, post_title FROM {$wpdb->posts}
            WHERE post_type = %s
            AND post_status = 'publish'
            ORDER BY post_date DESC
        ", $type ) );

        $options  = array( '' => __('All Products', 'tt-proven') );

        foreach ( $posts as $post ) {
            $options[$post->ID] = $post->post_title;
        }

        return $options;
    }

    
    /**
     * Add Woocommerce activity.
     *
     * @since 1.0.0
     * @return array
     */
    public function get_activity_data( $id )
    {
        if ( 'woocommerce' != get_post_meta( $id, '_tt_proven_source', true ) ) {
            return $data;
        }

		//Number of purcahses to show
		$number = get_post_meta( $id, '_tt_proven_number', true );
		
		//Specific product or all products
		$specific_product = get_post_meta( $id, '_tt_proven_purchases_woocommerce', true );

        if ( '' != $specific_product ) {
            $orders = self::get_orders_by_product( $specific_product, $number );
        } else {
            $orders = self::get_orders($number);
        }

        if ( ! $orders || empty( $orders ) ) {
            return $data;
        }

        rsort( $orders );

		$notification_order = get_post_meta( $id, '_tt_proven_order', true ); //Determine what order the notifications should be displayed
		if($notification_order == 'random'){
			shuffle($orders);
		}

        $product_id = $product_name = '';
		$link_to = get_post_meta( $id, '_tt_proven_link_to', true );

        foreach ( $orders as $order_id ) {

            if ( '' != get_post_meta( $id, '_tt_proven_purchases_woocommerce', true ) ) {
                $product_id     = $specific_product;
                $product_name   = get_the_title( $product_id );
            } else {
                // Get a product from order.
                $product        = self::get_product_from_order( $order_id );
                $product_id     = $product['data']['product_id'];
                $product_name   = $product['data']['name'];
            }

            if ( ! $product_id || empty( $product_id ) ) {
                continue;
            }

            // Get the billing details.
            $order_data = self::get_address( $order_id );
            $billing = $order_data['billing'];
            $time = human_time_diff(strtotime($order_data['date_created']), current_time( 'timestamp' ));

            ob_start();
            ?>
            <small><?php echo esc_html__( 'About', 'tt-proven' ) . ' ' . esc_html( $time ) . ' ' . esc_html__( 'ago', 'tt-proven' ) ?></small>
            <?php
            $time_ago = ob_get_clean();

            // Data to render notification.
            $activity_data = array(
                'title'     => $product_name,
                'name'      => $billing['first_name'],
                'email'     => $billing['email'],
                'city'      => $billing['city'],
                'state'     => $billing['state'],
                'country'   => $billing['country'],
                'time'      => $time_ago
            );

			if(!$activity_data['name']){
				$activity_data['name'] = __( 'Someone', 'tt-proven' );
			}

            // Product URL or Custom URL.
            if ( $link_to == 'product' ) {
                $activity_data['link_url'] = get_permalink( $product_id );
            }elseif($link_to == 'custom'){
				$activity_data['link_url'] = get_post_meta( $id, '_tt_proven_custom_url_ecommerce', true );
			}

            $data['fields'][] = $activity_data;
        }

        $data['template'] = get_post_meta( $id, '_tt_proven_content_ecommerce', true );

        return $data;
    }

    /**
	 * Returns the singleton instance of the class.
	 *
	 * @since 1.0.0
	 * @return object The TT_Proven_WooCommerce object.
	 */
	public static function get_instance()
	{
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof TT_Proven_WooCommerce ) ) {
			self::$instance = new TT_Proven_WooCommerce();
		}

		return self::$instance;
	}
}

$tt_proven_woocommerce = TT_Proven_WooCommerce::get_instance();
