<?php
/**
 * @category tt-proven
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

/**
 * Get the bootstrap! If using the plugin from wordpress.org, REMOVE THIS!
 */



if ( file_exists( TT_PROVEN_DIR . 'includes/cmb2/init.php' ) ) {
	require_once TT_PROVEN_DIR . 'includes/cmb2/init.php';
	require_once TT_PROVEN_DIR . 'includes/cmb2-conditionals/cmb2-conditionals.php';
	require_once TT_PROVEN_DIR . 'includes/cmb2-post-search-field/cmb2-post-search-field.php';
	
} elseif ( file_exists( TT_PROVEN_DIR . 'includes/CMB2/init.php' ) ) {
	require_once TT_PROVEN_DIR . 'includes/CMB2/init.php';
	require_once TT_PROVEN_DIR . 'includes/cmb2-conditionals/cmb2-conditionals.php';
	require_once TT_PROVEN_DIR . 'includes/cmb2-post-search-field/cmb2-post-search-field.php';
}




function get_source_options() {
    $integration_options = array();
    if ( class_exists( 'WooCommerce' ) ) {
		$integration_options[ 'woocommerce' ] = "Woocommerce";
	}
	
	if ( function_exists( 'EDD' ) ) {
		$integration_options[ 'edd' ] = "Easy Digital Downloads";
	}
	$integration_options[ 'mailchimp' ] = "MailChimp";
	$integration_options[ 'manual' ] = "Manual";
	
    return $integration_options;
}


//Configuration
add_action( 'cmb2_admin_init', 'tt_proven_register_metabox' );
add_action( 'cmb2_admin_init', 'cmb2_conditionals_init' );

function tt_proven_register_metabox() {
	$prefix = '_tt_proven_';
	
	// Configuration 

	$cmb_proven = new_cmb2_box( array(
		'id'            => $prefix . 'config',
		'title'         => __( 'Configuration', 'tt-proven' ),
		'object_types'  => array( 'tt_proven' ), // Post type
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Active', 'tt-proven' ),
		'id'               => $prefix . 'active',
		'type'             => 'select',
		'options'          => array(
			'1' => __( 'Yes', 'tt-proven' ),
			'0'   => __( 'No', 'tt-proven' ),
		),
	) );
	
	
	// Content 
	
	$cmb_proven = new_cmb2_box( array(
		'id'            => $prefix . 'content',
		'title'         => __( 'Content', 'tt-proven' ),
		'object_types'  => array( 'tt_proven' ), // Post type
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Source', 'tt-proven' ),
		'desc'             => __( 'Choose the source from which Proven will display info.', 'tt-proven' ),
		'id'               => $prefix . 'source',
		'type'             => 'select',
		'options'          => get_source_options(),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Content Template', 'tt-proven' ),
		'desc'             => __( 'Available template tags: {name}, {city}, {state}, {country}, {title}, {time}', 'tt-proven' ),
		'id'               => $prefix . 'content_ecommerce',
		'default' => 	__( "{name} from {state}\nPurchased {title}\n{time}", 'tt-proven' ),
		'type'             => 'textarea_small',
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'woocommerce', 'edd' ) ),
		),
		
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Purchases', 'tt-proven' ),
		'desc'             => __( 'Show purchases of all products or a single product.', 'tt-proven' ),
		'id'               => $prefix . 'purchases_woocommerce',
		'type'             => 'select',
		'options'          => TT_Proven_Woocommerce::get_products_list(),
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => 'woocommerce',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Content Template', 'tt-proven' ),
		'desc'             => __( 'Available template tags: {name}, {city}, {state}, {country}, {title}, {time}', 'tt-proven' ),
		'id'               => $prefix . 'content_mailchimp',
		'default' => 	__( "{name}\nSigned up for our newsletter\n{time}", 'tt-proven' ),
		'type'             => 'textarea_small',
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'mailchimp' ) ),
		),
		
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Mailing Lists', 'tt-proven' ),
		'id'               => $prefix . 'mailing_list',
		'type'             => 'select',
		'options'          => TT_Proven_MailChimp::get_mailing_lists(),
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => 'mailchimp',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Purchases', 'tt-proven' ),
		'desc'             => __( 'Show purchases of all products or a single product.', 'tt-proven' ),
		'id'               => $prefix . 'purchases_edd',
		'type'             => 'select',
		'options'          => TT_Proven_EDD::get_products_list(),
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => 'edd',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Number to Show', 'tt-proven' ),
		'id'               => $prefix . 'number',
		'desc'             => __( 'Choose the number of purchases to show.', 'tt-proven' ),
		'type'             => 'text_small',
		'default' => 	  '10',
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Link To', 'tt-proven' ),
		'id'               => $prefix . 'link_to',
		'type'             => 'select',
		'options'          => array(
			'none' => __( 'None', 'tt-proven' ),
			'product' => __( 'Product', 'tt-proven' ),
			'custom'   => __( 'Custom', 'tt-proven' ),
		),
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'woocommerce', 'edd' ) ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Custom Link URL', 'tt-proven' ),
		'id'               => $prefix . 'custom_url_ecommerce',
		'desc'             => __( 'Enter a url for the notifications to link to.', 'tt-proven' ),
		'type'             => 'text',
		'default' => 	  '',
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'link_to',
			'data-conditional-value' => wp_json_encode( array( 'custom') ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Link URL', 'tt-proven' ),
		'id'               => $prefix . 'custom_url_mailing_list',
		'desc'             => __( 'Enter a url for the notifications to link to.', 'tt-proven' ),
		'type'             => 'text',
		'default' => 	  '',
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'mailchimp') ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Link URL', 'tt-proven' ),
		'id'               => $prefix . 'custom_url_manual',
		'desc'             => __( 'Enter a url for the notifications to link to. This will be used if no link url is set on each entry.', 'tt-proven' ),
		'type'             => 'text',
		'default' => 	  '',
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'manual') ),
		),
	) );
	
	
	// Manual Entries
	$group_field_id = $cmb_proven->add_field( array(
		'id'          => $prefix . 'manual_group',
		'type'        => 'group',
		'repeatable'  => true, // use false if you want non-repeatable group
		'options'     => array(
			'group_title'   => __( 'Entry {#}', 'tt-proven' ), // since version 1.1.4, {#} gets replaced by row number
			'add_button'    => __( 'Add Another Entry', 'tt-proven' ),
			'remove_button' => __( 'Remove Entry', 'tt-proven' ),
			'sortable'      => true, // beta
			'closed'     => true, // true to have the groups closed by default
		),
		'attributes' => array(
			'required'               => false, // Will be required only if visible.
			'data-conditional-id'    => $prefix . 'source',
			'data-conditional-value' => wp_json_encode( array( 'manual') ),
		),
	) );

	$cmb_proven->add_group_field( $group_field_id, array(
		'name' => __( 'Content', 'tt-proven' ),
		'id'   => 'content',
		'type' => 'textarea_small',
		
	) );

	$cmb_proven->add_group_field( $group_field_id, array(
		'name' => __( 'Date & Time', 'tt-proven' ),
		'description' => __( 'Choose a date and time for the entry.', 'tt-proven' ),
		'id'   => 'date_time',
		'type' => 'text_datetime_timestamp',
	) );

	$cmb_proven->add_group_field( $group_field_id, array(
		'name' => __( 'Image', 'tt-proven' ),
		'description' => __( 'Upload an image of the customer.', 'tt-proven' ),
		'id'   => 'image',
		'type' => 'file',
	) );
	
	$cmb_proven->add_group_field( $group_field_id, array(
		'name'             => __( 'Link URL', 'tt-proven' ),
		'id'               => 'custom_url',
		'desc'             => __( 'Enter a url for this notification to link to.', 'tt-proven' ),
		'type'             => 'text',
		'default' => 	  '',
	) );


	// Behavior 
	
	$cmb_proven = new_cmb2_box( array(
		'id'            => $prefix . 'behavior',
		'title'         => __( 'Behavior', 'tt-proven' ),
		'object_types'  => array( 'tt_proven' ), // Post type
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Order', 'tt-proven' ),
		'id'               => $prefix . 'order',
		'type'             => 'select',
		'options'          => array(
			'newest-oldest' => __( 'Newest to Oldest', 'tt-proven' ),
			'random'   => __( 'Random', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Show On', 'tt-proven' ),
		'desc'             => __( 'Choose where to show Proven.', 'tt-proven' ),
		'id'               => $prefix . 'show_on',
		'type'             => 'select',
		'options'          => array(
			'all' => __( 'All Pages', 'tt-proven' ),
			'certain'   => __( 'Certain Pages', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'        => __( 'Show on These Pages', 'tt-proven' ),
		'id'          => $prefix . 'show_on_these_pages',
		'desc'             => __( 'Enter the ids of the pages on which Proven will be shown.', 'tt-proven' ),
		'type'        => 'post_search_text', 
		'post_type'   => array( 'post', 'page','product','download'),
		'select_type' => 'checkbox',
		'select_behavior' => 'replace',
		'attributes' => array(
			'required'               => false, 
			'data-conditional-id'    => $prefix . 'show_on',
			'data-conditional-value' => 'certain',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'        => __( 'Hide on These Pages', 'tt-proven' ),
		'id'          => $prefix . 'hide_on_these_pages',
		'desc'             => __( 'Enter the ids of the pages on which Proven will be hidden.', 'tt-proven' ),
		'type'        => 'post_search_text', 
		'post_type'   => array( 'post', 'page'),
		'select_type' => 'checkbox',
		'select_behavior' => 'replace',
		'attributes' => array(
			'required'               => false, 
			'data-conditional-id'    => $prefix . 'show_on',
			'data-conditional-value' => 'all',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Users', 'tt-proven' ),
		'desc'             => __( 'Choose which users will see Proven.', 'tt-proven' ),
		'id'               => $prefix . 'users',
		'type'             => 'select',
		'options'          => array(
			'all' => __( 'All', 'tt-proven' ),
			'logged-in'   => __( 'Logged In', 'tt-proven' ),
			'logged-out'   => __( 'Logged Out', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Visitors', 'tt-proven' ),
		'desc'             => __( 'Choose which visitors will see Proven.', 'tt-proven' ),
		'id'               => $prefix . 'visitors',
		'type'             => 'select',
		'options'          => array(
			'all' => __( 'All', 'tt-proven' ),
			'new'   => __( 'New', 'tt-proven' ),
			'returning'   => __( 'Returning', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Hide on Mobile', 'tt-proven' ),
		'id'               => $prefix . 'hide_on_mobile',
		'type'             => 'select',
		'options'          => array(
			'0' => __( 'No', 'tt-proven' ),
			'1'   => __( 'Yes', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Show Close Button', 'tt-proven' ),
		'id'               => $prefix . 'show_close',
		'type'             => 'select',
		'options'          => array(
			'1' => __( 'Yes', 'tt-proven' ),
			'0'   => __( 'No', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Initial Delay', 'tt-proven' ),
		'id'               => $prefix . 'delay_initial',
		'desc'             => __( 'Set how long to wait before showing first notification (in seconds).', 'tt-proven' ),
		'type'             => 'text_small',
		'default' => 	  '3',
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Display Time', 'tt-proven' ),
		'id'               => $prefix . 'duration',
		'desc'             => __( 'Set how long each item will be visible (in seconds).', 'tt-proven' ),
		'type'             => 'text_small',
		'default' => 	  '5',
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Delay Between', 'tt-proven' ),
		'id'               => $prefix . 'delay_between',
		'desc'             => __( 'Set how long of delay between notifications (in seconds).', 'tt-proven' ),
		'type'             => 'text_small',
		'default' => 	  '5',
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Animation', 'tt-proven' ),
		'id'               => $prefix . 'animation',
		'type'             => 'select',
		'options'          => array(
			'fade-in' => __( 'Fade In', 'tt-proven' ),
			'fade-up'   => __( 'Fade Up', 'tt-proven' ),
		),
	) );
	


	// Appearance 
	
	$cmb_proven = new_cmb2_box( array(
		'id'            => $prefix . 'appearance',
		'title'         => __( 'Appearance', 'tt-proven' ),
		'object_types'  => array( 'tt_proven' ), // Post type
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Position', 'tt-proven' ),
		'desc'             => __( 'Choose the position of Proven.', 'tt-proven' ),
		'id'               => $prefix . 'position',
		'type'             => 'select',
		'options'          => array(
			'bottom-left' => __( 'Bottom Left', 'tt-proven' ),
			'bottom-right'   => __( 'Bottom Right', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Shape', 'tt-proven' ),
		'desc'             => __( 'Choose the shape of the Proven box.', 'tt-proven' ),
		'id'               => $prefix . 'shape',
		'type'             => 'select',
		'options'          => array(
			'shape-completely-rounded'   => __( 'Completely Rounded', 'tt-proven' ),
			'shape-slightly-rounded' => __( 'Slightly Rounded', 'tt-proven' ),
			'shape-squared'   => __( 'Squared', 'tt-proven' ),
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Background Color', 'tt-proven' ),
		'id'               => $prefix . 'background_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
		'options' => array(
			'alpha' => true,
		),
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'First Line Text Color', 'tt-proven' ),
		'desc'             => __( 'Color for the first line of text.', 'tt-proven' ),
		'id'               => $prefix . 'text_color_first_line',
		'type'    => 'colorpicker',
		'default' => '#000',
	) );
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Text Color', 'tt-proven' ),
		'desc'             => __( 'Color for all other text.', 'tt-proven' ),
		'id'               => $prefix . 'text_color',
		'type'    => 'colorpicker',
		'default' => '#000',
	) );
	
	
	$cmb_proven->add_field( array(
		'name'             => __( 'Shadow Intensity', 'tt-proven' ),
		'id'               => $prefix . 'shadow',
		'type'             => 'select',
		'options'          => array(
			'shadow-0' => '0',
			'shadow-1' => '1',
			'shadow-2' => '2',
			'shadow-3' => '3',
			'shadow-4' => '4',
			'shadow-5' => '5',
		),
	) );
	
	$cmb_proven->add_field( array(
		'name' => __( 'Default Image', 'create' ),
		'desc' => __( 'This image will appear if a user image is not available.', 'tt-proven' ),
		'id'   => $prefix . 'default_img',
		'type' => 'file',
	) );
}





