<?php

// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'TT_PROVEN_STORE_URL', 'http://themetrust.com' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the name of your product. This should match the download name in EDD exactly
define( 'TT_PROVEN_ITEM_NAME', 'Proven' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the id of your product. This should match the download id in EDD exactly
define( 'TT_PROVEN_ITEM_ID', 1319660 ); // you should use your own CONSTANT name, and be sure to replace it throughout this file

// the name of the settings page for the license input to be displayed
define( 'TT_PROVEN_LICENSE_PAGE', 'proven-settings' );

if( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	// load our custom updater
	include( dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php' );
}

add_filter( 'edd_sl_api_request_verify_ssl', '__return_false' );

function tt_proven_plugin_updater() {
	// retrieve our license key from the DB
	$license_key = trim( get_option( 'tt_proven_license_key' ) );

	// setup the updater
	$edd_updater = new EDD_SL_Plugin_Updater( TT_PROVEN_STORE_URL, TT_PROVEN_MAIN_FILE, array(
			'version' 	=> TT_PROVEN_VER, 				// current version number
			'license' 	=> $license_key, 		// license key (used get_option above to retrieve from DB)
			'item_name' => TT_PROVEN_ITEM_NAME, 	// name of this plugin
			'item_id'     => TT_PROVEN_ITEM_ID,
			'author' 	=> 'ThemeTrust',  // author of this plugin
			'beta'		=> false
		)
	);
}
add_action( 'admin_init', 'tt_proven_plugin_updater', 0 );


function tt_proven_sanitize_license( $new ) {
	$old = get_option( 'tt_proven_license_key' );
	if( $old && $old != $new ) {
		delete_option( 'tt_proven_license_status' ); // new license has been entered, so must reactivate
	}
	return $new;
}


/************************************
* this illustrates how to activate
* a license key
*************************************/

function tt_proven_activate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['tt_proven_license_activate'] ) ) {

		// run a quick security check
	 	if( ! check_admin_referer( 'tt_proven_license_activate_nonce', 'tt_proven_license_activate_nonce' ) )
			return; // get out if we didn't click the Activate button


		// get the license key
		$license = '';
		if ( isset( $_POST['tt_proven_license_key'] ) ) {
            $license = tt_proven_sanitize_license( $_POST['tt_proven_license_key'] );
            update_option( 'tt_proven_license_key', esc_attr( $license ) );
        }
		
		// data to send in our API request
		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => $license,
			'item_name'  => urlencode( TT_PROVEN_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( TT_PROVEN_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.' );
			}

		} else {

			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			if ( false === $license_data->success ) {

				switch( $license_data->error ) {

					case 'expired' :

						$message = sprintf(
							__( 'Your license key expired on %s.' ),
							date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
						);
						break;

					case 'revoked' :

						$message = __( 'Your license key has been disabled.' );
						break;

					case 'missing' :

						$message = __( 'Invalid license.' );
						break;

					case 'invalid' :
					case 'site_inactive' :

						$message = __( 'Your license is not active for this URL.' );
						break;

					case 'item_name_mismatch' :

						$message = sprintf( __( 'This appears to be an invalid license key for %s.' ), TT_PROVEN_ITEM_NAME );
						break;

					case 'no_activations_left':

						$message = __( 'Your license key has reached its activation limit.' );
						break;

					default :

						$message = __( 'An error occurred, please try again.' );
						break;
				}

			}

		}

		// Check if anything passed on a message constituting a failure
		if ( ! empty( $message ) ) {
			$base_url = Proven_Admin::get_form_action();
			$redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

			wp_redirect( $redirect );
			exit();
		}

		// $license_data->license will be either "valid" or "invalid"

		update_option( 'tt_proven_license_status', $license_data->license );
		wp_redirect( Proven_Admin::get_form_action() );
		exit();
	}
}
add_action('admin_init', 'tt_proven_activate_license');


/***********************************************
* Illustrates how to deactivate a license key.
* This will decrease the site count
***********************************************/

function tt_proven_deactivate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['tt_proven_license_deactivate'] ) ) {

		// run a quick security check
	 	if( ! check_admin_referer( 'tt_proven_license_deactivate_nonce', 'tt_proven_license_deactivate_nonce' ) )
			return; // get out if we didn't click the Activate button

		// retrieve the license from the database
		$license = trim( get_option( 'tt_proven_license_key' ) );


		// data to send in our API request
		$api_params = array(
			'edd_action' => 'deactivate_license',
			'license'    => $license,
			'item_name'  => urlencode( TT_PROVEN_ITEM_NAME ), // the name of our product in EDD
			'url'        => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post( TT_PROVEN_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

			if ( is_wp_error( $response ) ) {
				$message = $response->get_error_message();
			} else {
				$message = __( 'An error occurred, please try again.' );
			}

			$base_url = Proven_Admin::get_form_action();
			$redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

			wp_redirect( $redirect );
			exit();
		}

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "deactivated" or "failed"
		if( $license_data->license == 'deactivated' ) {
			delete_option( 'tt_proven_license_status' );
		}

		wp_redirect( Proven_Admin::get_form_action() );
		exit();

	}
}
add_action('admin_init', 'tt_proven_deactivate_license');


/************************************
* this illustrates how to check if
* a license key is still valid
* the updater does this for you,
* so this is only needed if you
* want to do something custom
*************************************/

function tt_proven_check_license() {

	global $wp_version;

	$license = trim( get_option( 'tt_proven_license_key' ) );

	$api_params = array(
		'edd_action' => 'check_license',
		'license' => $license,
		'item_name' => urlencode( TT_PROVEN_ITEM_NAME ),
		'url'       => home_url()
	);

	// Call the custom API.
	$response = wp_remote_post( TT_PROVEN_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

	if ( is_wp_error( $response ) )
		return false;

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );

	if( $license_data->license == 'valid' ) {
		echo 'valid'; exit;
		// this license is still valid
	} else {
		echo 'invalid'; exit;
		// this license is no longer valid
	}
}

/**
 * This is a means of catching errors from the activation method above and displaying it to the customer
 */
function tt_proven_admin_notices() {
	if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {

		switch( $_GET['sl_activation'] ) {

			case 'false':
				$message = urldecode( $_GET['message'] );
				?>
				<div class="error">
					<p><?php echo $message; ?></p>
				</div>
				<?php
				break;

			case 'true':
			default:
				// Developers can put a custom success message here for when activation is successful if they way.
				break;

		}
	}
}
add_action( 'admin_notices', 'tt_proven_admin_notices' );